package Mqv2r_3.KQgRr5e_0.KQgRr5e_0.QxJ9d_1.IFxWkV_5;

import android.media.session.PlaybackState;
import android.os.Bundle;
import java.util.List;
/* compiled from: PlaybackStateCompatApi21.java */
/* loaded from: classes.dex */
public class X6FRs_4 {

    /* compiled from: PlaybackStateCompatApi21.java */
    /* loaded from: classes.dex */
    public static final class KQgRr5e_0 {
        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public static String m148KQgRr5e_0(Object obj) {
            return ((PlaybackState.CustomAction) obj).getAction();
        }

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public static CharSequence m147KQgRr5e_0(Object obj) {
            return ((PlaybackState.CustomAction) obj).getName();
        }

        public static int KQgRr5e_0(Object obj) {
            return ((PlaybackState.CustomAction) obj).getIcon();
        }

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public static Bundle m146KQgRr5e_0(Object obj) {
            return ((PlaybackState.CustomAction) obj).getExtras();
        }
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public static int m142KQgRr5e_0(Object obj) {
        return ((PlaybackState) obj).getState();
    }

    public static long Mqv2r_3(Object obj) {
        return ((PlaybackState) obj).getLastPositionUpdateTime();
    }

    public static long PGPF6hQ_2(Object obj) {
        return ((PlaybackState) obj).getBufferedPosition();
    }

    public static long QxJ9d_1(Object obj) {
        return ((PlaybackState) obj).getActiveQueueItemId();
    }

    public static long X6FRs_4(Object obj) {
        return ((PlaybackState) obj).getPosition();
    }

    public static float KQgRr5e_0(Object obj) {
        return ((PlaybackState) obj).getPlaybackSpeed();
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public static long m143KQgRr5e_0(Object obj) {
        return ((PlaybackState) obj).getActions();
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public static CharSequence m144KQgRr5e_0(Object obj) {
        return ((PlaybackState) obj).getErrorMessage();
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public static List<Object> m145KQgRr5e_0(Object obj) {
        return ((PlaybackState) obj).getCustomActions();
    }
}
